@@ -1,4 +1,3 @@
-
 /**
  * Module dependencies.
  */
@@ -15,8 +14,8 @@ var crypto = require('crypto');
  */
 
 exports.sign = function(val, secret){
-  if ('string' != typeof val) throw new TypeError('cookie required');
-  if ('string' != typeof secret) throw new TypeError('secret required');
+  if ('string' != typeof val) throw new TypeError("Cookie value must be provided as a string.");
+  if ('string' != typeof secret) throw new TypeError("Secret string must be provided.");
   return val + '.' + crypto
     .createHmac('sha256', secret)
     .update(val)
@@ -35,8 +34,13 @@ exports.sign = function(val, secret){
  */
 
 exports.unsign = function(val, secret){
-  if ('string' != typeof val) throw new TypeError('cookie required');
-  if ('string' != typeof secret) throw new TypeError('secret required');
-  var str = val.slice(0, val.lastIndexOf('.'));
-  return exports.sign(str, secret) == val ? str : false;
+  if ('string' != typeof val) throw new TypeError("Signed cookie string must be provided.");
+  if ('string' != typeof secret) throw new TypeError("Secret string must be provided.");
+  var str = val.slice(0, val.lastIndexOf('.'))
+    , mac = exports.sign(str, secret)
+    , macBuffer = Buffer.from(mac)
+    , valBuffer = Buffer.alloc(macBuffer.length);
+
+  valBuffer.write(val);
+  return crypto.timingSafeEqual(macBuffer, valBuffer) ? str : false;
 };
